local SharedMedia = AceLibrary("SharedMedia-1.0")
SharedMedia:Register("font", "Blend", "Interface\\AddOns\\PitBull\\Fonts\\Blend.ttf")

local barSpacing = 1
local portraitOffset = 2
local iconSize = 18

local function getBarHeight(frame)
	local height = frame:GetHeight()
	
	if frame.powerBar then
		return (height / 2) - (barSpacing / 2)
	else
		return height
	end
end


PitBull:RegisterLayout("Blend", {
	-- Bars
	healthBar = function(unit, frame)
		frame.healthBar:SetPoint("TOP", frame, "TOP", 0, 0)
		frame.healthBar:SetPoint("LEFT", frame, "LEFT", 0, 0)
		frame.healthBar:SetPoint("RIGHT", frame, "RIGHT", 0, 0)
		frame.healthBar:SetHeight(getBarHeight(frame))
	end,
	
	powerBar = function(unit, frame)
		if frame.healthBar then
			frame.powerBar:SetPoint("TOP", frame.healthBar, "BOTTOM", 0, -barSpacing)
		else
			frame.powerBar:SetPoint("TOP", frame, "TOP", 0, 0)
		end

		frame.powerBar:SetPoint("LEFT", frame, "LEFT", 0, 0)
		frame.powerBar:SetPoint("RIGHT", frame, "RIGHT", 0, 0)
		frame.powerBar:SetHeight(getBarHeight(frame))
	end,
	
	castBar = function(unit, frame)
		if frame.group == "target" then
			frame.castBar:SetPoint("TOPLEFT", UIParent, "CENTER", 100, 0)
			frame.castBar:SetWidth(frame:GetWidth())
			frame.castBar:SetHeight(getBarHeight(frame))
		end
	end,
	
	castBarIcon = function(unit, frame)
		local size = getBarHeight(frame)
		
		frame.castBarIcon:SetHeight(size)
		frame.castBarIcon:SetWidth(size)
		frame.castBarIcon:SetPoint("RIGHT", frame.castBar, "LEFT", -barSpacing, 0)
		frame.castBarIcon:SetTexCoord(0.07, 0.93, 0.07, 0.93)
	end,
	
	castBarText = function(unit, frame)
		frame.castBarText:ClearAllPoints()
		frame.castBarText:SetPoint("TOPLEFT", frame.castBar, "TOPLEFT", 2, 0)
		frame.castBarText:SetPoint("BOTTOMRIGHT", frame.castBar, "BOTTOMRIGHT", 2, 0)
	end,
	
	castBarTimeText = function(unit, frame)
		frame.castBarTimeText:ClearAllPoints()
		frame.castBarTimeText:SetPoint("TOPLEFT", frame.castBar, "TOPLEFT", 2, 0)
		frame.castBarTimeText:SetPoint("BOTTOMRIGHT", frame.castBar, "BOTTOMRIGHT", -2, 0)
		frame.castBarTimeText:SetJustifyH("RIGHT")
	end,

	comboText = function(unit, frame)
		frame.comboText:SetFont(PitBull:GetFont(), 22)
		frame.comboText:SetPoint("RIGHT", frame, "LEFT", -11, 0)
	end,
	
	combatIcon = function(unit, frame)
		frame.combatIcon:SetPoint("CENTER", frame.healthBar, "TOP", 0, 0)
		frame.combatIcon:SetWidth(iconSize)
		frame.combatIcon:SetHeight(iconSize)
	end,
	
	restIcon = function(unit, frame)
		if frame.combatIcon then
			frame.restIcon:SetPoint("LEFT", frame.combatIcon, "RIGHT", 0, 0)
		else
			frame.restIcon:SetPoint("CENTER", frame.healthBar, "TOP", 0, 0)
		end

		frame.restIcon:SetWidth(iconSize)
		frame.restIcon:SetHeight(iconSize)
	end,
	
	leaderIcon = function(unit, frame)
		frame.leaderIcon:SetPoint("CENTER", frame, "TOP", 0, 0)
		frame.leaderIcon:SetWidth(14)
		frame.leaderIcon:SetHeight(14)
	end,
})
